==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridColumnSummaryOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
import { GridColumnSummaryOptionsDescription } from "./GridColumnSummaryOptionsDescription";
/**
 * @hidden
 */
var GridColumnSummaryOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnSummaryOptionsDescriptionMetadata, _super);
    function GridColumnSummaryOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnSummaryOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnSummaryOptionsDescriptionMetadata.a == null) {
            GridColumnSummaryOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnSummaryOptionsDescriptionMetadata.c(GridColumnSummaryOptionsDescriptionMetadata.a);
        }
        if (a.g(GridColumnSummaryOptionsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridColumnSummaryOptionsDescriptionMetadata.a);
    };
    GridColumnSummaryOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
        a.item("SummaryCaption", "String");
        a.item("SummaryListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("SummaryListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualSummaryListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualSummaryListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActiveCount", "Number:int");
    };
    GridColumnSummaryOptionsDescriptionMetadata.d = function (a) {
        GridColumnSummaryOptionsDescriptionMetadata.b(a);
        a.u("GridColumnSummaryOptions", function () { return new GridColumnSummaryOptionsDescription(); });
        a.t("GridColumnSummaryOptions", GridColumnSummaryOptionsDescriptionMetadata.a);
    };
    GridColumnSummaryOptionsDescriptionMetadata.$t = markType(GridColumnSummaryOptionsDescriptionMetadata, 'GridColumnSummaryOptionsDescriptionMetadata');
    GridColumnSummaryOptionsDescriptionMetadata.a = null;
    return GridColumnSummaryOptionsDescriptionMetadata;
}(Base));
export { GridColumnSummaryOptionsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridColumnSummaryOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
import { GridColumnSummaryOptionsDescription } from "./GridColumnSummaryOptionsDescription";
/**
 * @hidden
 */
var GridColumnSummaryOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnSummaryOptionsDescriptionMetadata, _super);
    function GridColumnSummaryOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnSummaryOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnSummaryOptionsDescriptionMetadata.a == null) {
            GridColumnSummaryOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnSummaryOptionsDescriptionMetadata.c(GridColumnSummaryOptionsDescriptionMetadata.a);
        }
        if (a.j(GridColumnSummaryOptionsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridColumnSummaryOptionsDescriptionMetadata.a);
    };
    GridColumnSummaryOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
        a.item("SummaryCaption", "String");
        a.item("SummaryListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("SummaryListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActualSummaryListDensity", "ExportedType:string:ControlDisplayDensity");
        a.item("ActualSummaryListDensity@names", "Auto;Comfortable;Cosy;Compact");
        a.item("ActiveCount", "Number:int");
    };
    GridColumnSummaryOptionsDescriptionMetadata.d = function (a) {
        GridColumnSummaryOptionsDescriptionMetadata.b(a);
        a.aa("GridColumnSummaryOptions", function () { return new GridColumnSummaryOptionsDescription(); });
        a.z("GridColumnSummaryOptions", GridColumnSummaryOptionsDescriptionMetadata.a);
    };
    GridColumnSummaryOptionsDescriptionMetadata.$t = markType(GridColumnSummaryOptionsDescriptionMetadata, 'GridColumnSummaryOptionsDescriptionMetadata');
    GridColumnSummaryOptionsDescriptionMetadata.a = null;
    return GridColumnSummaryOptionsDescriptionMetadata;
}(Base));
export { GridColumnSummaryOptionsDescriptionMetadata };
